==> mooli-docs-1.3.0.tgz: package/site/desktop/components/Header/searchInput.jsx <==
import React, { useEffect } from 'react';

const searchConfig = {
  apiKey: '90067aecdaa2c85220e2783cd305caac',
  indexName: 'vant',
  placeholder: '搜索文档...',
  algoliaOptions: {
    facetFilters: ['version:v2'],
  },
};

const SearchInput = () => {
  const initDocSearch = () => {
    const { algoliaOptions } = searchConfig;
    let facetFilters = [`lang: zh-CN`];

    if (algoliaOptions?.facetFilters) {
      facetFilters = facetFilters.concat(algoliaOptions.facetFilters);
    }
    // @ts-ignore
    window.docsearch({
      ...searchConfig,
      transformData: (hits) => {
        hits.forEach((hit) => {
          if (hit.anchor) {
            hit.url = `${hit.url}#${hit.anchor}`;
            hit.anchor = null;
          }
        });
        if (searchConfig.transformData) {
          searchConfig.transformData(hits);
        }
      },
      inputSelector: '.search-input',
      algoliaOptions: {
        ...algoliaOptions,
        facetFilters,
      },
    });
  };

  useEffect(() => {
    initDocSearch();
  }, []);
  return (
    <div className="search-container">
      <i className="search-icon">
        <svg className="icon" width="1em" height="1em" viewBox="0 0 1024 1024">
          <path
            d="M915.8 852.9L766.9 706.7c47.4-62.8 75.9-140.7 75.9-225.5 0-207-167.8-374.9-374.9-374.9-207.1 0.1-374.9 167.9-374.9 375s167.8 374.9 374.9 374.9c95.4 0 182.2-35.9 248.4-94.6L865.4 908c14.7 14.4 37.8 13.8 51.7-1.4 13.9-15.2 13.3-39.3-1.3-53.7zM467.9 790c-170.5 0-308.7-138.2-308.7-308.7s138.2-308.7 308.7-308.7 308.7 138.2 308.7 308.7S638.4 790 467.9 790z m0 0"
            fill="#999999"
          />
        </svg>
      </i>
      <input className="search-input" placeholder="搜索组件" />
    </div>
  );
};

export default SearchInput;

==> mooli-docs-1.3.8.tgz: package/site/desktop/components/Header/searchInput.jsx <==
import React, { useEffect } from 'react';

const searchConfig = {
  apiKey: '90067aecdaa2c85220e2783cd305caac',
  indexName: 'vant',
  placeholder: '搜索文档...',
  algoliaOptions: {
    facetFilters: ['version:v2'],
  },
};

const SearchInput = () => {
  const initDocSearch = () => {
    const { algoliaOptions } = searchConfig;
    let facetFilters = [`lang: zh-CN`];

    if (algoliaOptions?.facetFilters) {
      facetFilters = facetFilters.concat(algoliaOptions.facetFilters);
    }
    // @ts-ignore
    // window.docsearch({
    //   ...searchConfig,
    //   transformData: (hits) => {
    //     hits.forEach((hit) => {
    //       if (hit.anchor) {
    //         hit.url = `${hit.url}#${hit.anchor}`;
    //         hit.anchor = null;
    //       }
    //     });
    //     if (searchConfig.transformData) {
    //       searchConfig.transformData(hits);
    //     }
    //   },
    //   inputSelector: '.search-input',
    //   algoliaOptions: {
    //     ...algoliaOptions,
    //     facetFilters,
    //   },
    // });
  };

  useEffect(() => {
    initDocSearch();
  }, []);
  return (
    <div className="search-container">
      <i className="search-icon">
        <svg className="icon" width="1em" height="1em" viewBox="0 0 1024 1024">
          <path
            d="M915.8 852.9L766.9 706.7c47.4-62.8 75.9-140.7 75.9-225.5 0-207-167.8-374.9-374.9-374.9-207.1 0.1-374.9 167.9-374.9 375s167.8 374.9 374.9 374.9c95.4 0 182.2-35.9 248.4-94.6L865.4 908c14.7 14.4 37.8 13.8 51.7-1.4 13.9-15.2 13.3-39.3-1.3-53.7zM467.9 790c-170.5 0-308.7-138.2-308.7-308.7s138.2-308.7 308.7-308.7 308.7 138.2 308.7 308.7S638.4 790 467.9 790z m0 0"
            fill="#999999"
          />
        </svg>
      </i>
      <input className="search-input" placeholder="搜索组件" />
    </div>
  );
};

export default SearchInput;
